@@ -86,7 +86,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -133,6 +133,12 @@
 #else
 #  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_102(text) KGLOBALACCEL_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KGLOBALACCEL_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_4_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -199,7 +205,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56700
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -209,7 +215,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x56200
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x56700
 #  endif
 #endif
 
@@ -246,6 +252,12 @@
 #else
 #  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text)
 #endif
+
+#if KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE >= 0x56600
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_102(text) KGLOBALACCEL_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KGLOBALACCEL_DEPRECATED_VERSION_5_102(text)
+#endif
 #define KGLOBALACCEL_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_4_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
